@@ -229,8 +229,8 @@ impl Client {
         // Send the dummy message to probe the network for it's infrastructure details.
         while attempts < NETWORK_PROBE_RETRY_COUNT && initial_probe.is_err() {
             error!(
-                "Initial probe msg to network failed. Trying again, attempt: {}",
-                attempts
+                "Initial probe msg to network failed. Trying again (attempt {}): {:?}",
+                attempts, initial_probe
             );
 
             if attempts == NETWORK_PROBE_RETRY_COUNT {
